@@ -1,6 +1,6 @@
 package UV::Handle;
 
-our $VERSION = '1.000002';
+our $VERSION = '1.000003';
 $VERSION = eval $VERSION;
 
 use strict;
@@ -9,12 +9,6 @@ use Exporter qw(import);
 
 use UV;
 
-our @EXPORT_OK  = qw(
-    UV_ASYNC UV_CHECK UV_FS_EVENT UV_FS_POLL
-    UV_IDLE UV_NAMED_PIPE UV_POLL UV_PREPARE UV_PROCESS
-    UV_STREAM UV_TCP UV_TIMER UV_TTY UV_UDP UV_SIGNAL UV_FILE
-);
-
 1;
 
 __END__
