@@ -1,6 +1,6 @@
 package UV::Loop;
 
-our $VERSION = '1.000002';
+our $VERSION = '1.000003';
 $VERSION = eval $VERSION;
 
 use strict;
@@ -9,10 +9,6 @@ use Exporter qw(import);
 
 use UV;
 
-our @EXPORT_OK  = qw(
-    UV_RUN_DEFAULT UV_RUN_ONCE UV_RUN_NOWAIT UV_LOOP_BLOCK_SIGNAL SIGPROF
-);
-
 1;
 
 __END__
