@@ -1,16 +1,12 @@
 package UV::Poll;
 
-our $VERSION = '1.000002';
+our $VERSION = '1.000003';
 $VERSION = eval $VERSION;
 
 use strict;
 use warnings;
 
 use parent 'UV::Handle';
-our @EXPORT_OK  = qw(
-    UV_READABLE UV_WRITABLE UV_DISCONNECT UV_PRIORITIZED
-);
-
 
 
 1;
